pub struct EndpointCatalog { /* private fields */ }Expand description
Ordered endpoint catalog with duplicate identity and route-shape detection.
Implementations
Sourceimpl EndpointCatalog
impl EndpointCatalog
Sourcepub fn register(&mut self, endpoint: EndpointMetadata) -> SoapResult<()>
pub fn register(&mut self, endpoint: EndpointMetadata) -> SoapResult<()>
Registers one validated endpoint.
Sourcepub fn register_all<I>(&mut self, endpoints: I) -> SoapResult<()>where
I: IntoIterator<Item = EndpointMetadata>,
pub fn register_all<I>(&mut self, endpoints: I) -> SoapResult<()>where
I: IntoIterator<Item = EndpointMetadata>,
Atomically registers every endpoint or leaves the catalog unchanged.
Sourcepub fn endpoint(&self, id: &EndpointId) -> Option<&EndpointMetadata>
pub fn endpoint(&self, id: &EndpointId) -> Option<&EndpointMetadata>
Returns one endpoint by stable identity.
Sourcepub fn route(
&self,
method: &Method,
path: &RoutePath,
) -> Option<&EndpointMetadata>
pub fn route( &self, method: &Method, path: &RoutePath, ) -> Option<&EndpointMetadata>
Returns one endpoint by method and declared portable route shape.
Sourcepub fn endpoints(&self) -> &[EndpointMetadata]
pub fn endpoints(&self) -> &[EndpointMetadata]
Returns endpoints in deterministic registration order.
Sourcepub fn into_endpoints(self) -> Vec<EndpointMetadata>
pub fn into_endpoints(self) -> Vec<EndpointMetadata>
Consumes the catalog into deterministic endpoint order.