pub struct EndpointContracts { /* private fields */ }Expand description
Request and response contracts attached to one endpoint.
Implementations
Sourceimpl EndpointContracts
impl EndpointContracts
Sourcepub fn add_request(&mut self, contract: RequestContract)
pub fn add_request(&mut self, contract: RequestContract)
Adds or replaces the contract for one request location.
Sourcepub fn add_response(&mut self, contract: ResponseContract)
pub fn add_response(&mut self, contract: ResponseContract)
Adds or replaces the response contract for one status code.
Sourcepub fn requests(&self) -> &[RequestContract]
pub fn requests(&self) -> &[RequestContract]
Returns request contract references in registration order.
Sourcepub fn responses(&self) -> &[ResponseContract]
pub fn responses(&self) -> &[ResponseContract]
Returns response contract references in registration order.